#
# spec file for package vnstat
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1210
%bcond_without systemd
%else
%bcond_with systemd
%endif
Name:           vnstat
Version:        1.17
Release:        lp150.1.4
Summary:        Network Traffic Monitor
License:        GPL-2.0
Group:          Productivity/Networking/Diagnostic
Url:            http://humdi.net/vnstat
Source:         http://humdi.net/vnstat/vnstat-%{version}.tar.gz
Source1:        vnstat-if.sh
Source2:        vnstat-cgi.conf
Source3:        vnstat-create-db.sh
Source4:        vnstat.init
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gd-devel
BuildRequires:  glibc-devel
Requires:       %{_bindir}/killall
Requires:       /bin/ls
Requires:       /bin/su
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with systemd}
BuildRequires:  systemd
%{?systemd_requires}
%else
Requires(pre):  %fillup_prereq
Requires(pre):  %insserv_prereq
%endif

%description
vnStat is a network traffic monitor for Linux that keeps a log of
daily network traffic for the selected interface(s). vnStat isn't a
packet sniffer. The traffic information is analyzed from the /proc
filesystem, so vnStat can be used without root permissions.

%package cgi
Summary:        Graph Visualization CGI Script for %{name}
Group:          Productivity/Networking/Diagnostic
Requires:       %{name} = %{version}
Recommends:     apache2

%description cgi
vnStat is a network traffic monitor for Linux that keeps a log of
daily network traffic for the selected interface(s). vnStat isn't a
packet sniffer. The traffic information is analyzed from the /proc
filesystem, so vnStat can be used without root permissions.

This package contains a CGI script that visualizes graphs of the
collected traffic statistics.

%prep
%setup -q
# Add user and group to the systemd service.
sed -i 's/\(\[Service\]\)/\1\nUser=vnstat\nGroup=vnstat/' examples/systemd/vnstat.service

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_localstatedir}/lib/vnstat/

install -Dm 0755 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/network/scripts/vnstat
for state in up down; do
    mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/network/if-${state}.d/
    ln -s ../scripts/vnstat %{buildroot}%{_sysconfdir}/sysconfig/network/if-${state}.d/20-vnstat
done

install -Dm 0755 examples/vnstat.cgi %{buildroot}/srv/vnstat/vnstat.cgi
install -Dm 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/apache2/conf.d/vnstat.conf

install -Dm 0755 %{SOURCE3} %{buildroot}%{_bindir}/vnstat-create-db

%if %{with systemd}
install -Dm 0644 examples/systemd/vnstat.service %{buildroot}%{_unitdir}/vnstatd.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcvnstatd
%else
install -Dm 0755 %{SOURCE4} %{buildroot}%{_initddir}/vnstatd
mkdir -p %{buildroot}%{_sbindir}/
ln -s %{_initddir}/vnstatd %{buildroot}%{_sbindir}/rcvnstatd
%endif

%pre
%{_sbindir}/groupadd -r vnstat &> /dev/null || :
%{_sbindir}/useradd -g vnstat -s /bin/sh -r -c "vnstat daemon" -d %{_localstatedir}/lib/vnstat vnstat &>/dev/null ||:
%if 0%{?with_systemd}
%service_add_pre vnstatd.service
%endif

%post
%if %{with systemd}
%service_add_post vnstatd.service
%else
%fillup_and_insserv vnstatd
%endif

%preun
%if %{with systemd}
%service_del_preun vnstatd.service
%else
%stop_on_removal vnstatd
%endif

%postun
%if %{with systemd}
%service_del_postun vnstatd.service
%else
%restart_on_update vnstatd
%insserv_cleanup
%endif

%files
%defattr(-,root,root)
%doc CHANGES COPYING FAQ README UPGRADE
%config(noreplace) %{_sysconfdir}/vnstat.conf
%{_sysconfdir}/sysconfig/network/scripts/vnstat
%{_sysconfdir}/sysconfig/network/if-up.d/20-vnstat
%{_sysconfdir}/sysconfig/network/if-down.d/20-vnstat
%{_bindir}/vnstat-create-db
%{_bindir}/vnstat
%{_sbindir}/vnstatd
%{_sbindir}/rcvnstatd
%if %{with systemd}
%{_unitdir}/vnstatd.service
%else
%{_initddir}/vnstatd
%endif
%{_mandir}/man1/vnstat.1%{?ext_man}
%{_mandir}/man1/vnstatd.1%{?ext_man}
%{_mandir}/man5/vnstat.conf.5%{?ext_man}
%attr(0755,vnstat,root) %{_localstatedir}/lib/vnstat

%files cgi
%defattr(-,root,root)
%dir %{_sysconfdir}/apache2/
%dir %{_sysconfdir}/apache2/conf.d/
%config(noreplace) %{_sysconfdir}/apache2/conf.d/vnstat.conf
%{_bindir}/vnstati
%{_mandir}/man1/vnstati.1.gz
/srv/vnstat/

%changelog
* Tue Feb 21 2017 liedke@rz.uni-mannheim.de
- Update to 1.17:
  * Fix: --importdb was creating invalid databases since version
    1.15
  * Fix: console output was being buffered which resulted in lack
    of output in at least systemd log
  * Add cross-compilation detection and improve install-data-hook
    to not assume that the binaries can be executed in the host
    system
- Update to 1.16:
  * Fix: traffic rate calculation, SI decimal prefixes were shown
    but calculation was done for IEC binary prefixes
  * Add option for configure to disable image output support even
    if required library is available, improve library detection
  * Add selection between SI decimal prefixes (kbit/s...) (default)
    and IEC binary prefixes (Kibit/s...) for traffic rate using
    RateUnitMode keyword in configuration file
  * Improve database handling resilience
  * Inherit database file ownership from database directory if
    UpdateFileOwner configuration option is enabled (default:
    enabled) when adding new interfaces for monitoring as root.
    This solves database file ownership mismatches when the daemon
    is started as a non-root user and an interface gets added for
    monitoring with a sudo command as root
  * Improve user guidance in error situations related to the
    configured default interface
* Sat Mar  5 2016 sor.alexei@meowr.ru
- Update to 1.15:
  * Fix: XML output had extra commas, broken since previous version.
  * Fix: unintended shared pointer modification in mosecs()
    sometimes resulted in wrong month name to be shown for the
    current month.
  * Fix possible buffer overflow in /proc/net/dev parsing, requires
    corrupted content in /proc/net/dev or use of address sanitiser.
  * Use ANSI escape codes in -l and -tr modes for cursor location
    manipulation instead of printing backspaces, hide cursor while
    output is active.
  * Improve database import robustness.
  * Improve support for Asian UTF-8 date strings.
  * Replace hand written Makefiles with autotools.
  * Add --alwaysadd parameter to daemon for allowing automatic
    addition of interfaces even if the database directory was
    populated during startup.
* Tue Aug 18 2015 Mathias.Homann@opensuse.org
- Fix: vnstati was missing from build, needed for vnstat-cgi to function.
* Tue Aug  4 2015 sor.alexei@meowr.ru
- Update to 1.14 (changes since 1.11):
  * Fix memory allocation when zero interfaces are available,
    also lo needed to be missing in order to trigger this leak.
  * Fix rebuild total indexing.
  * Fix some error situations that could leave database file open
    until the end of command execution
  * Fix: Live traffic meter occasionally showing higher minimum
    than average in end statistics.
  * Fix setting locale when none is specified in config.
  * Fix cppcheck findings.
  * Improve traffic meter output accuracy.
  * Add tests and debug compilation target.
  * Remove use of -D parameter in Makefile install commands in
    order to improve cross-compilation support.
  * Set CFLAGS in Makefiles only when not already defined.
  * Add support for database import from text file (--importdb).
  * Rename --dumpdb to --exportdb.
  * Add example systemd service file.
  * Use ISO YYYY-MM-DD date format timestamps if logfile is used.
  * Improve daemon startup prints.
  * Add parameters for changing daemon process user and group.
  * Add example upstart job configuration file.
  * Create database, pid and log dirs during daemon startup if
    necessary.
  * Update ownership of database, log and pid files if needed
    during daemon startup if started as root and configured to
    change process user and group.
  * Remove cron update related example files and documentation, the
    cron update method should be considered as deprecated.
  * --create parameter for database creation.
  * Dynamic unit selection in hourly output instead of being fixed
    to KiB.
  * New options in image output (vnstati):
    + -nl / --nolegend for hiding the rx/tx legend;
    + --altdate for using alternative date and time text location;
    + --headertext for using custom text string in image header;
    section.
  * Add legend to hourly output image.
  * Add option for content alignment and page background colour to
    vnstat.cgi.
  * Document keyword value ranges in configuration file man page.
  * Import Makefile improvements from OpenBSD.
  * Automatic interface bandwidth detection, BandwidthDetection in
    config, default fallback value MaxBandwidth changed from 100 to
    1000.
  * JSON output (--json), vnstat-json.cgi and vnstat-json.php
    examples provided in the 'examples' directory
  * Drop support for over 10 year old database formats
    (versions 1.0 - 1.2).
  * Fix: JSON output syntax during first day of newly created
    databases.
  * Fix: field padding when using UTF-8 locale.
  * Add optional mode parameter to --json and --xml for limiting
    the output to only selected information.
- Add a systemd service.
- Remove vnstat-cron.patch and cronjob: upstream considers it
  deprecated.
- Remove vnstat-help_script.patch: fixed upstream.
- Only recommend Apache for vnstat-cgi: there are other HTTP
  servers.
- Spec cleanup.
* Sun Aug 10 2014 chris+dev@any.mx
- removed '-u' parameter from init.d script to actually being able to start the daemon
* Wed Jul 31 2013 cwh@suse.com
- Fixed spec file (removed lost pach files)
* Sun Jul  7 2013 lars@linux-schulserver.de
- remove the '-o' option in useradd: -o is useless without -u and
  newer versions of pwdutils/shadowutils fail on this now
- specfile cleanup (added license header and cron dependency)
- fix address of Free Software Foundation in init script
* Mon Feb  4 2013 lars@linux-schulserver.de
- update to 1.11:
  * Fix: Memory allocation was miscalculated when creating interface list from
    /sys/class/net when /proc/net/dev wasn't available which in turn could
    crash the daemon
  * Fix: Daemon database cache could remain empty after a -HUP signal
  * Fix: Don't make temp directory in vnstat.cgi writable for everyone
  * Import GNU/kFreeBSD support from Debian
  (#608963, patch by Mats Erik Andersson)
  * Remove usage of GNU only '-D' option for install for BSD in Makefile
  * The daemon now automatically creates databases for available interfaces
  if no databases are found during startup
* Mon Feb  4 2013 lars@linux-schulserver.de
- prevent cron from writing a syslog message about the vnstat call
* Sat Aug 21 2010 highwaystar.ru@gmail.com
- update to 1.10:
  * Fix: Buffer overflow was possible in hourly image output when RateUnit=1
  and HourlyRate=1
  * Fix: Minor memory leak was possible in the handling of HUP signal in daemon
  * Fix: Graphical elements weren't correctly aligned in summary image
  when header wasn't visible (-nh)
  * Fix: --delete didn't work
  * Possibility to merge statistics from several databases and save
  the end result to a new database (--mergesaved)
  * Added validation of database cache in daemon in order to be more robust
  in case of system memory corruption
  * Support for --style to -l (live mode)
  * Alternative print mode to -l (live mode) with optional parameter
  * Present options and elements in man pages in alphabetical order
  * Code cleanup
- changes in 1.9:
  * Fix: TrafficlessDays configuration option was enabled when set to zero
  when it should have been disabled
  * Fix: MonthRotate setting was getting ignored for the first month if
  the database is created when day of month < MonthRotate value
  * Configurable summary layout in image output (1.7 <> 1.8 layouts)
  * --oneline, a simple parseable one line output
  * --transparent for setting image background transparency from the
  command line
  * --delete for deleting databases and stopping monitoring, doesn't require
  restarting the daemon
  * A database write can be configure to occur after interface status changes
  * Different database write interval can be configure to be used when
  all monitored interfaces are offline
  * Better configurability for the content of outputs, including a narrow
  output for space limited terminals (OutputStyle and --style)
  * Code cleanup
  * New configuration file settings:
  OutputStyle, SummaryLayout, SummaryRate, SaveOnStatusChange,
  OfflineSaveInterval
* Wed Aug 19 2009 poeml@suse.de
- fix segfault caused by vnstat-limits+su.patch.
  vnstat-limits+su+fix.patch added.
* Sun Aug  2 2009 pascal.bleser@opensuse.org
- update to 1.8:
  * makes averaged traffic rates visible
  * adds monthly traffic to the summary
  * supports merging data from multiple interfaces to one output
  * dates are now formatted according to the system locale setting by default
* Tue May 26 2009 poeml@novell.com
- change ownership also of existing backup files of the database
- ignore '.' and '..' when modifying files -- the previous method could change
  the ownership of /var/lib...
* Tue May 26 2009 poeml@novell.com
- move creation of "vnstat" user from %%post to %%pre, so that it happens before
  files are installed
- make vnstat a system user and create a separate group "vnstat" for it
- prerequire the tools needed for the pre/post scripts
- change ownership of existing databases from root to vnstat user, when updating
* Mon May 25 2009 pascal.bleser@opensuse.org
- don't filter out br interfaces, thanks to Dmitry Mittov for noticing
* Fri May 15 2009 pascal.bleser@opensuse.org
- add a little frontend script to create the vnstat databases as the vnstat user
- add patch to vnstat help output to tell to use the script to create a database
* Fri May 15 2009 pascal.bleser@opensuse.org
- install hook scripts into /etc/ppp/*.d/
- install CGI + patch heavily, using a subpackage vnstat-cgi
- add support for vnstatd (added in 1.7) with init script, vnstat user, and an improved cron job file
- add switch user support during daemonization to vnstatd
- fix all compile warnings
- update to 1.7:
  * Fix: Timezone changes shouldn't cause a flood of errors anymore
  * Fix: MonthRotate value in config wasn't used
  * Fix: Unreadable configuration file doesn't cause a segmentation fault
  * Fix: /proc/net/dev parser didn't see the difference between eth10 and eth1
  * Fix: Updating a database from two of more processes at the same time was able to sometimes cause data loss
  * Fix: Estimates are calculated based on last database update
  * Fix: Each interface update had a possibility of losing 1023 bytes of traffic at most due to improper rounding
  * Daemon support as alternative for cron based updates
  * PNG image output (hourly rate based on patch by Sergio Ammirata)
  * XML output
  * Diskspace check can be disabled from configuration file
  * IEC standard prefixes (KiB/MiB/GiB/TiB)
  * List of available interfaces if wrong of unavailable interface is selected
* Wed Feb 20 2008 poeml@suse.de
- update to 1.6:
  1.6 / 1-Jan-08
  - Fix: Segmentation fault when environment variable "HOME" wasn't defined,
    this broke most CGI and PHP scripts that used vnStat
  - Support for /sys/class/net/* if /proc/net/dev is unavailable
  - Config file parser redesigned
  - --config parameter for selecting config file
  - Consistent exit status for all operations (0 for success, 1 for error)
  - Improved file locking
  - Man page restrictions paragraph updated
  - Minor non-visible fixes and code cleanup
  1.5 / 3-Dec-07
  - Fix: compile time warnings solved
  - Fix: kernel test is now more verbose
  - Fix: more informative error messages
  - Fix: possible division by zero for traffic estimates right after midnight
  - Fix: interface names longer than 6 chars (patch by Jan Schmidle)
  - Realtime transfer rate mode
  - Automatic 32bit/64bit counter detection
  - Config file support
  - Internal database backups and locking
  - More visuals in outputs
  - Adaptive units (kB, MB, GB, TB)
  - Possibility to sync counters without counting traffic
  - Maximum bandwidth of interfaces can be set
* Wed Feb 20 2008 poeml@suse.de
- re-import the package sources from 10.1, they got lost
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jul  2 2005 hvogel@suse.de
- make use of optflags
* Mon Jun  6 2005 hvogel@suse.de
- add suse.de- prefix to the cron script
* Tue Feb 15 2005 hvogel@suse.de
- Use "-" in cron file to suppress syslog message
* Tue Feb  8 2005 hvogel@suse.de
- New Package, Version 1.4
